# WGDI

[![Latest PyPI version](https://img.shields.io/pypi/v/wgdi.svg)](https://pypi.python.org/pypi/wgdi)

| | |
| --- | --- |
| Author  | Pengchuan Sun ([sunpengchuan](https//github.com/sunpengchuan)) |
| Email   | <sunpengchuan@gmail.com> |
| License | [BSD](http://creativecommons.org/licenses/BSD/) |

## Description

Finely identify the whole genome duplication events and generate the genomic homology tables. This is a gold standard for complex genomic analysis,including the construction of homologous gene dotplot, event-related genomic alignment, and synonymous substitutions, and differences in different evolution rates, etc.

## Installation

Python package and command line interface (CLI) for the analysis of whole genome duplications (WGDs). 安装需要的环境是python3. 

```bash
pip3 install wgdi
```

For **external software** requirements: please consult the relevant section in the docs: <https://wgdi.readthedocs.io/en/latest/index.html#external-software>

To use as a Python package as well as to find additional documentation and examples for the CLI, please consult the docs at<http://wgdi.readthedocs.io/en/latest/>



## Third party software

paml

mafft

muscle

pal2nal